core.wirings.OfflineModule - core

#

API Docs for: 0.0.2
Show: Inherited Protected Private Deprecated

# core.wirings.OfflineModule Class

Extends core.wirings.Module
Defined in: `addons/webapp/OfflineModule.js:4`
Module: addons

The main class that implements offline webapp functionalities using application cache and local storage. Extends core.wirings.Module to have the ability to be instantiated in the same fashion.

## Constructor

### `core.wirings.OfflineModule`

(

- `opts`

)

Defined in `addons/webapp/OfflineModule.js:4`

#### Parameters:

- `opts` Object

  An object containing configurations required by the Core derived class.

  - `el` HTMLElement

    The node element included in the class composition.

- Index
- Methods

## Item Index

### Methods

- cacheStatus
- onApplicationCacheStatus
- onlineStatus

## Methods

### `cacheStatus`

(

- `status`

)

Defined in `addons/webapp/OfflineModule.js:97`

Virtual protected function. Should be overridden on subclasses. Called automatically when the cache status has changed.

#### Parameters:

- `status` String

  The status of the application cache.

### `onApplicationCacheStatus`

(

- `event`

)

Defined in `addons/webapp/OfflineModule.js:40`

The main method handler for checking the application status. Also determines if a web application has gone offline/online

#### Parameters:

- `event` Object

  Contains the information about the current application cache status.

### `onlineStatus`

(

- `isonline`

)

Defined in `addons/webapp/OfflineModule.js:106`

Virtual protected function. Should be overridden on subclasses. Called automatically when the online/offline state of the application changes.

#### Parameters:

- `isonline` Boolean

  True/false depending on the applications online/offline state.